@@ -19,7 +19,7 @@ fn bench_create_witness<E: Engine, const NUM_COEFFS: usize>(c: &mut Criterion) {
         coeffs[i] = rng.gen::<u64>().into();
     }
     let polynomial: Polynomial<E, NUM_COEFFS> = Polynomial::new_from_coeffs(coeffs, NUM_COEFFS - 1);
-    let mut prover = KZGProver::new(params);
+    let mut prover = KZGProver::new(&params);
     let _commitment = prover.commit(polynomial.clone());
 
 	let x: E::Fr = rng.gen::<u64>().into();
